@@ -11,10 +11,10 @@ def test_get():
     assert len(response['institutions']) == 3
 
 
-def test_get_with_include_institution_data():
+def test_get_with_include_optional_metadata():
     client = create_client()
     response = client.Institutions.get(3, offset=1, _options={
-        'include_institution_data': True,
+        'include_optional_metadata': True,
     })
     assert len(response['institutions']) == 3
     assert len(response['institutions'][0]['url']) > 0
@@ -36,10 +36,10 @@ def test_get_by_id():
     assert response['institution']['institution_id'] == SANDBOX_INSTITUTION
 
 
-def test_get_by_id_with_include_institution_data():
+def test_get_by_id_with_include_optional_metadata():
     client = create_client()
     response = client.Institutions.get_by_id(SANDBOX_INSTITUTION, _options={
-        'include_institution_data': True,
+        'include_optional_metadata': True,
     })
     assert response['institution']['institution_id'] == SANDBOX_INSTITUTION
 
@@ -57,10 +57,10 @@ def test_search_with_products():
     assert len(response['institutions']) >= 1
 
 
-def test_search_with_include_institution_data():
+def test_search_with_include_optional_metadata():
     client = create_client()
     response = client.Institutions.search(
         SANDBOX_INSTITUTION_NAME, _options={
-            'include_institution_data': True,
+            'include_optional_metadata': True,
         })
     assert len(response['institutions']) >= 1
